@@ -75,9 +75,8 @@ sub build {
 
 sub install {
 	my $this=shift;
-	my $destdir=shift;
 	foreach my $command ($this->pybuild_commands('install', @_)) {
-		doit(@$command, '--dest-dir', $destdir);
+		doit(@$command);
 	}
 }
 
@@ -113,6 +112,14 @@ sub pybuild_commands {
 		push @options, '--quiet';
 	}
 
+	# Pass dh's destdir, if it's not the default value
+	if ($step eq 'install') {
+		my $destdir = shift(@options);
+		if ($destdir ne "debian/tmp") {
+			push @options, "--dest-dir=$destdir";
+		}
+	}
+
 	my @deps;
 	if ($ENV{'PYBUILD_INTERPRETERS'}) {
 		push @result, ['pybuild', "--$step", @options];
